summaryrefslogtreecommitdiff
path: root/examples/webkitwidgets/imageanalyzer/imageanalyzer.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'examples/webkitwidgets/imageanalyzer/imageanalyzer.cpp')
-rw-r--r--examples/webkitwidgets/imageanalyzer/imageanalyzer.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/examples/webkitwidgets/imageanalyzer/imageanalyzer.cpp b/examples/webkitwidgets/imageanalyzer/imageanalyzer.cpp
index 97fff64..2152f86 100644
--- a/examples/webkitwidgets/imageanalyzer/imageanalyzer.cpp
+++ b/examples/webkitwidgets/imageanalyzer/imageanalyzer.cpp
@@ -1,7 +1,7 @@
/****************************************************************************
**
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
**
** This file is part of the examples of the Qt Toolkit.
**
@@ -17,9 +17,9 @@
** notice, this list of conditions and the following disclaimer in
** the documentation and/or other materials provided with the
** distribution.
** * Neither the name of Digia Plc and its Subsidiary(-ies) nor the names
** of its contributors may be used to endorse or promote products derived
** from this software without specific prior written permission.
**
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
@@ -138,7 +138,7 @@ void ImageAnalyzer::fetchURLs()
// HTTP Get image over network.
m_outstandingFetches++;
QNetworkRequest request = QNetworkRequest(URL);
- request.setRawHeader("User-Agent", "Digia - Custom Qt app");
+ request.setRawHeader("User-Agent", "The Qt Company Ltd. - Custom Qt app");
m_network->get(request);
} else {
// Get image from cache
@@ -17,9 +17,9 @@
** the documentation and/or other materials provided with the
** distribution.
-** * Neither the name of Digia Plc and its Subsidiary(-ies) nor the names
-** of its contributors may be used to endorse or promote products derived
-** from this software without specific prior written permission.
+** * Neither the name of The Qt Company Ltd and its Subsidiary(-ies) nor the
+** names of its contributors may be used to endorse or promote products
+** derived from this software without specific prior written permission.
**
**